==> gtkmathview_0.6.4.orig.tar.gz: gtkmathview-0.6.4/src/engine/mathml/MathMLElement.cc <==
// Copyright (C) 2000-2003, Luca Padovani <luca.padovani@cs.unibo.it>.
//
// This file is part of GtkMathView, a Gtk widget for MathML.
// 
// GtkMathView is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// GtkMathView is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with GtkMathView; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// 
// For details, see the GtkMathView World-Wide-Web page,
// http://helm.cs.unibo.it/mml-widget, or send a mail to
// <luca.padovani@cs.unibo.it>

#include <config.h>

#include <cassert>

#include "AttributeList.hh"
#include "MathMLElement.hh"
#include "MathMLOperatorElement.hh"
#include "MathMLNamespaceContext.hh"
#include "ValueConversion.hh"
#include "Variant.hh"

MathMLElement::MathMLElement(const SmartPtr<MathMLNamespaceContext>& context) : Element(context)
{ }

MathMLElement::~MathMLElement()
{ }

AreaRef
MathMLElement::format(MathFormattingContext& ctxt)
{
  if (dirtyLayout())
    {
      setArea(0);
      resetDirtyLayout();
    }

  return getArea();
}

bool
MathMLElement::IsSpaceLike() const
{
  return false;
}

SmartPtr<MathMLOperatorElement>
MathMLElement::getCoreOperator()
{
  return 0;
}

SmartPtr<MathMLOperatorElement>
MathMLElement::getCoreOperatorTop()
{
  if (SmartPtr<MathMLOperatorElement> coreOp = getCoreOperator())
    {
      SmartPtr<MathMLElement> parent = getParent<MathMLElement>();
      if (!parent || parent->getCoreOperator() != coreOp)
	return coreOp;
    }
  return 0;
}

SmartPtr<MathMLNamespaceContext>
MathMLElement::getMathMLNamespaceContext() const
{ return smart_cast<MathMLNamespaceContext>(getNamespaceContext()); }

==> gtkmathview_0.6.5.orig.tar.gz: gtkmathview-0.6.5/src/engine/mathml/MathMLElement.cc <==
// Copyright (C) 2000-2003, Luca Padovani <luca.padovani@cs.unibo.it>.
//
// This file is part of GtkMathView, a Gtk widget for MathML.
// 
// GtkMathView is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// GtkMathView is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with GtkMathView; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// 
// For details, see the GtkMathView World-Wide-Web page,
// http://helm.cs.unibo.it/mml-widget, or send a mail to
// <luca.padovani@cs.unibo.it>

#include <config.h>

#include <cassert>

#include "AttributeSet.hh"
#include "MathMLElement.hh"
#include "MathMLOperatorElement.hh"
#include "MathMLNamespaceContext.hh"
#include "ValueConversion.hh"
#include "Variant.hh"

MathMLElement::MathMLElement(const SmartPtr<MathMLNamespaceContext>& context) : Element(context)
{ }

MathMLElement::~MathMLElement()
{ }

bool
MathMLElement::IsSpaceLike() const
{
  return false;
}

SmartPtr<MathMLOperatorElement>
MathMLElement::getCoreOperator()
{
  return 0;
}

SmartPtr<MathMLOperatorElement>
MathMLElement::getCoreOperatorTop()
{
  if (SmartPtr<MathMLOperatorElement> coreOp = getCoreOperator())
    {
      SmartPtr<MathMLElement> parent = getParent<MathMLElement>();
      if (!parent || parent->getCoreOperator() != coreOp)
	return coreOp;
    }
  return 0;
}

SmartPtr<MathMLNamespaceContext>
MathMLElement::getMathMLNamespaceContext() const
{ return smart_cast<MathMLNamespaceContext>(getNamespaceContext()); }
